@@ -1,22 +1,3 @@
-
-"coda.global.assign" <- function(name, value, alias=FALSE)
-{
-  ## Utility function to overcome some incompatibilities between
-  ## S and R when creating global variables.
-  #
-  if(is.R()) {
-    ## R - assign to global environment
-    if(alias)
-      assign(name, value, pos=1)  
-    else
-      assign(name, value, pos=1)          
-  }
-  else {
-    ## S - assign to session database
-    assign(name, value, where=0)          
-  }
-}
-
 "read.yesno" <-
 function (string, default=TRUE)
 {
@@ -48,6 +29,9 @@ function (string, option)
 "coda.options" <-
 function (...) 
 {
+  if (!is.R()) {
+    stop("This function is not yet available in S-PLUS")
+  }
   ## Set and display coda options
   single <- FALSE
   if (!exists(".Coda.Options", frame = 1)) 
@@ -111,10 +95,8 @@ function (...)
         "Ranges such as 3:7 may be specified)", sep = "\n")
     if (allow.zero) 
       cat("(Enter 0 for none)\n")
-    if (is.R()) 
-      ans <- scan(what = character(), sep = ",", strip.white = TRUE, 
-                  nlines = 1, quiet = TRUE)
-    else ans <- scan(what = character(), sep = ",", strip.white = TRUE)
+    ans <- scan(what = character(), sep = ",", strip.white = TRUE, 
+                nlines = 1, quiet = TRUE)
     if (length(ans) > 0) {
       out <- numeric(0)
       for (i in 1:length(ans)) {
@@ -262,6 +244,8 @@ function (...)
        data.saved = TRUE
        )
 
+".Coda.Options" <- ".Coda.Options.Default"
+
 
 
 
